Module seaplane_cli::api

source ·
Wrapping seaplane SDK calls with things like CLI specific contexts, errors, etc.

Structs

Wraps an SDK FormationsRequest where we do additional things like re-use request access tokens, allow changing the Formation this request is pointed to, and map errors appropriately.
Wraps an SDK LocksRequest where we do additional things like re-use request access tokens, allow changing the Locks this request is pointed to, and map errors appropriately.
Wraps an SDK MetadataRequest where we do additional things like re-use request access tokens, allow changing the Formation this request is pointed to, and map errors appropriately.
Wraps an SDK RestrictRequest where we do additional things like re-use request access tokens, and map errors appropriately.

Functions

Makes a request against the /token endpoint of FlightDeck using the discovered API key and returns the short lived Access token response.
Follows the same process as request_token but only returns the raw JWT string part of the token