pub struct LocksReq { /* private fields */ }
Wraps an SDK LocksRequest where we do additional things like re-use request access tokens, allow changing the Locks this request is pointed to, and map errors appropriately.

Implementations

Request a new Access Token

Retrieves the JWT access token, requesting a new one if required.

Gets a page of held locks from dir if present (or the root) if not, optionally starting from next_key