Struct seaplane_cli::cli::cmds::flight::common::SeaplaneFlightCommonArgMatches
source · pub struct SeaplaneFlightCommonArgMatches<'a>(pub &'a ArgMatches);Expand description
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if
values of arguments were used or not. i.e. seaplane formation plan may not have the same
arguments as seaplane account token even though both produce an ArgMatches.
Tuple Fields
0: &'a ArgMatchesAuto Trait Implementations
impl<'a> !RefUnwindSafe for SeaplaneFlightCommonArgMatches<'a>
impl<'a> Send for SeaplaneFlightCommonArgMatches<'a>
impl<'a> Sync for SeaplaneFlightCommonArgMatches<'a>
impl<'a> Unpin for SeaplaneFlightCommonArgMatches<'a>
impl<'a> !UnwindSafe for SeaplaneFlightCommonArgMatches<'a>