Re-exports

pub use common::Provider;
pub use common::Region;

Modules

The common args effectively represent a “Formation Configuration” which many commands can include.

Structs

A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e. seaplane formation plan may not have the same arguments as seaplane account token even though both produce an ArgMatches.