Module seaplane_cli::cli::cmds::locks
source · Structs
- A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e.
seaplane locks acquiremay not have the same arguments asseaplane account tokeneven though both produce anArgMatches. - A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e.
seaplane formation createmay not have the same arguments asseaplane account tokeneven though both produce anArgMatches.