pub struct SeaplaneLocksAcquire;
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e. seaplane locks acquire may not have the same arguments as seaplane account token even though both produce an ArgMatches.

Implementations