Module common

Module common 

Structs

SeaplaneRestrictCommonArgMatches
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e. seaplane formation create may not have the same arguments as seaplane account token even though both produce an ArgMatches.

Enums

Provider
We provide a shim between the Seaplane Provider so we can do some additional UX work like ‘all’
Region
We provide a shim between the Seaplane Region so we can do some additional UX work

Functions

api
base64
directory
display_args
restriction_details