Function seaplane_cli::cli::validator::validate_path
source · pub fn validate_path(path: &str) -> StdResult<String, String>Expand description
The value may be path where path is some path that exists
pub fn validate_path(path: &str) -> StdResult<String, String>The value may be path where path is some path that exists