validate_public_endpoint

Function validate_public_endpoint 

pub fn validate_public_endpoint(s: &str) -> Result<Endpoint, String>
Ensures a valid Public Endpoint, we must special case Public Endpoints because it only supports the ‘http’ and ‘https’ protocol field.