Struct seaplane_cli::context::formation::FormationCtx
source · pub struct FormationCtx {
pub name_id: Option<FormationNameId>,
pub launch: bool,
pub remote: bool,
pub local: bool,
pub flights: Vec<FlightCtx>,
pub gateway_flight: Option<String>,
pub indices: Option<Vec<usize>>,
}Expand description
Represents the “Source of Truth” i.e. it combines all the CLI options, ENV vars, and config values into a single structure that can be used later to build models for the API or local structs for serializing
A somewhat counter-intuitive thing about Formations and their models is the there is no “Formation Model” only a “Formation Configuration Model” This is because a “Formation” so to speak is really just a named collection of configurations and info about their traffic weights/activation statuses.
Fields
name_id: Option<FormationNameId>launch: boolremote: boollocal: boolflights: Vec<FlightCtx>gateway_flight: Option<String>indices: Option<Vec<usize>>Implementations
sourceimpl FormationCtx
impl FormationCtx
sourcepub fn model(&self) -> Result<FormationModel>
pub fn model(&self) -> Result<FormationModel>
Creates a new seaplane::api::compute::v2::Formation from the contained values