Struct seaplane_cli::context::Args
source · pub struct Args {
pub color: ColorChoice,
pub overwrite: Vec<String>,
pub exact: bool,
pub all: bool,
pub third_party: bool,
pub shell: Option<Shell>,
pub out_format: OutputFormat,
pub force: bool,
pub stateless: bool,
pub api_key: Option<String>,
pub fetch: bool,
}Fields
color: ColorChoicewhen the answer is “yes…but only if the stream is a TTY.” In these cases an enum of Never, Auto, Always would be more appropriate
Should be display ANSI color codes in output?
overwrite: Vec<String>The raw name or local ID of an item What to overwrite
exact: boolDo items need to be exact to match
all: boolMatch all items
third_party: boolDisplay third party licenses
shell: Option<Shell>The shell to generate completions for
out_format: OutputFormatHow to display output
force: boolTry to force the operation to happen
stateless: boolDo not use local state files
api_key: Option<String>The API Key associated with an account provided by the CLI, env, or Config used to request access tokens
fetch: boolShould we fetch remote refs?