Module seaplane_cli::error

source ·

Structs

Enums

Traits

A trait for adding context to an error that will be printed along with the error. Contexts are useful for adding things such as hints (i.e. try –help), or additional information such as the path name on a PermissionDenied error, etc.

Type Definitions