Structs

A struct that writes to a tempfile and persists to a given location atomically on Drop

Traits

Functions

Finds all appropriate configuration directories in a platform specific manner
A utility function to get the correct data directory