Trait seaplane_cli::fs::FromDisk

source ·
pub trait FromDisk {
    fn set_loaded_from<P: AsRef<Path>>(&mut self, _p: P) { ... }
    fn loaded_from(&self) -> Option<&Path> { ... }
    fn load_if<P: AsRef<Path>>(p: P, yes: bool) -> Option<Result<Self>>
    where
        Self: Sized + DeserializeOwned
, { ... } fn load<P: AsRef<Path>>(p: P) -> Result<Self>
    where
        Self: Sized + DeserializeOwned
, { ... } }

Provided Methods

Allows one to save or deserialize what path the item was loaded from

If saved, get the path the item was loaded from

Only load from disk if yes is true, otherwise return None

Deserialize from some given path

Implementors