Struct seaplane_cli::ops::db::Db

source ·
pub struct Db {
    pub state_version: StateVersion,
    pub formations: Formations,
    pub needs_persist: bool,
    /* private fields */
}
The in memory “Databases”

Fields

state_version: StateVersionformations: Formations

The in memory Formations database

needs_persist: bool

A hint that we should persist at some point. Not gospel

Implementations

source

impl Db

source

pub fn load_and_upgrade(ctx: &Ctx) -> Result<Self>

Try to load the earliest state possible and upgrade to current. State will be persisted at the current version.