Module seaplane_cli::ops::metadata

source ·

Structs

We use our own KeyValue instead of the models because we need to not enforce base64 encoding, and implement a bunch of additional methods and traits that wouldn’t make sense for the models