Module restrict

Module restrict 

Structs

RestrictedDirectory
We use our own RestrictedDirectory instead of the models because we need to not enforce base64 encoding, and implement a bunch of additional methods and traits that wouldn’t make sense for the models
Restrictions