pub struct RestrictedDirectory {
    pub directory: EncodedString,
}
We use our own RestrictedDirectory instead of the models because we need to not enforce base64 encoding, and implement a bunch of additional methods and traits that wouldn’t make sense for the models

We also need to keep track if the values are encoded or not

Fields

directory: EncodedString

Implementations

Creates a new RestrictedDirectory from an encoded directory. The directory must be URL safe base64 encoded or Bad Things may happen.

Creates a new RestrictedDirectoryModel from self’s data.