pub struct Pb(_);
We wrap the progress bar to be able to hide output when we need to
TypeId
self
Returns the argument unchanged.
Span
Instrumented
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
From<T> for U
Subscriber
WithDispatch