Module seaplane_cli::api
source · Expand description
Wrapping seaplane SDK calls with things like CLI specific contexts, errors, etc.
Structs
- Wraps an SDK
FormationsRequestwhere we do additional things like re-use request access tokens, allow changing the Formation this request is pointed to, and map errors appropriately. - Wraps an SDK
LocksRequestwhere we do additional things like re-use request access tokens, allow changing the Locks this request is pointed to, and map errors appropriately. - Wraps an SDK
MetadataRequestwhere we do additional things like re-use request access tokens, allow changing the Formation this request is pointed to, and map errors appropriately. - Wraps an SDK
RestrictRequestwhere we do additional things like re-use request access tokens, and map errors appropriately.
Functions
- Makes a request against the
/tokenendpoint of FlightDeck using the discovered API key and returns the short lived Access token response. - Follows the same process as
request_tokenbut only returns the raw JWT string part of the token