Struct seaplane_cli::api::LocksReq
source · [−]pub struct LocksReq { /* private fields */ }Expand description
Wraps an SDK LocksRequest where we do additional things like re-use request access
tokens, allow changing the Locks this request is pointed to, and map errors appropriately.
Implementations
sourceimpl LocksReq
impl LocksReq
pub fn new(ctx: &Ctx) -> Result<Self>
pub fn set_identifiers<S: Into<String>>(
&mut self,
name: Option<LockName>,
lock_id: Option<S>
) -> Result<()>
pub fn set_name(&mut self, name: LockName) -> Result<()>
sourcepub fn refresh_token(&mut self) -> Result<()>
pub fn refresh_token(&mut self) -> Result<()>
Request a new Access Token
sourcepub fn token_or_refresh(&mut self) -> Result<&str>
pub fn token_or_refresh(&mut self) -> Result<&str>
Retrieves the JWT access token, requesting a new one if required.