The common args effectively represent a “Formation Configuration” which many commands can include.

The only additional information is the formation name, which is not part of the configuration, but many commands need as well.

Enums

We provide a shim between the Seaplane Provider so we can do some additional UX work like ‘all’
We provide a shim between the Seaplane Region so we can do some additional UX work

Functions