Struct seaplane_cli::cli::cmds::formation::SeaplaneFormationPlanArgMatches
source · pub struct SeaplaneFormationPlanArgMatches<'a>(pub &'a ArgMatches);Expand description
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if
values of arguments were used or not. i.e. seaplane formation plan may not have the same
arguments as seaplane account token even though both produce an ArgMatches.
Tuple Fields
0: &'a ArgMatchesAuto Trait Implementations
impl<'a> !RefUnwindSafe for SeaplaneFormationPlanArgMatches<'a>
impl<'a> Send for SeaplaneFormationPlanArgMatches<'a>
impl<'a> Sync for SeaplaneFormationPlanArgMatches<'a>
impl<'a> Unpin for SeaplaneFormationPlanArgMatches<'a>
impl<'a> !UnwindSafe for SeaplaneFormationPlanArgMatches<'a>