Struct seaplane_cli::cli::cmds::locks::SeaplaneLocksCommonArgMatches
source · pub struct SeaplaneLocksCommonArgMatches<'a>(pub &'a ArgMatches);Expand description
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if
values of arguments were used or not. i.e. seaplane formation create may not have the same
arguments as seaplane account token even though both produce an ArgMatches.
Tuple Fields
0: &'a ArgMatchesAuto Trait Implementations
impl<'a> !RefUnwindSafe for SeaplaneLocksCommonArgMatches<'a>
impl<'a> Send for SeaplaneLocksCommonArgMatches<'a>
impl<'a> Sync for SeaplaneLocksCommonArgMatches<'a>
impl<'a> Unpin for SeaplaneLocksCommonArgMatches<'a>
impl<'a> !UnwindSafe for SeaplaneLocksCommonArgMatches<'a>