Struct seaplane_cli::cli::cmds::metadata::SeaplaneMetadataSetArgMatches
source · pub struct SeaplaneMetadataSetArgMatches<'a>(pub &'a ArgMatches);Expand description
A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if
values of arguments were used or not. i.e. seaplane formation create may not have the same
arguments as seaplane account token even though both produce an ArgMatches.
Tuple Fields
0: &'a ArgMatchesAuto Trait Implementations
impl<'a> !RefUnwindSafe for SeaplaneMetadataSetArgMatches<'a>
impl<'a> Send for SeaplaneMetadataSetArgMatches<'a>
impl<'a> Sync for SeaplaneMetadataSetArgMatches<'a>
impl<'a> Unpin for SeaplaneMetadataSetArgMatches<'a>
impl<'a> !UnwindSafe for SeaplaneMetadataSetArgMatches<'a>