Structs

A newtype wrapper to enforce where the ArgMatches came from which reduces errors in checking if values of arguments were used or not. i.e. seaplane formation create may not have the same arguments as seaplane account token even though both produce an ArgMatches.

Enums

We provide a shim between the Seaplane Provider so we can do some additional UX work like ‘all’
We provide a shim between the Seaplane Region so we can do some additional UX work

Functions