Module validator

Module validator 

Utility functions used to validate various argument types on the CLI. The arguments and return type are what the clap::Arg::validator expects.

Functions

validate_at_path
The value may be @path where path is some path that exists
validate_at_stdin
The value may be @-
validate_endpoint
Ensures a valid Endpoint
validate_flight_name
Rules:
validate_formation_name
Current Rules:
validate_id
The value may be a up to a 32byte hex encoded string
validate_inline_flight_spec
The value may be:
validate_name_id
The arg can be any of:
validate_name_id_path
The arg can be any of:
validate_name_id_path_inline
The arg can be any of:
validate_public_endpoint
Ensures a valid Public Endpoint, we must special case Public Endpoints because it only supports the ‘http’ and ‘https’ protocol field.
validate_u64