Utility functions used to validate various argument types on the CLI. The arguments and return
type are what the clap::Arg::validator expects.
Functions
- validate_
at_ path - The value may be
@pathwherepathis some path that exists - validate_
at_ stdin - The value may be
@- - validate_
endpoint - Ensures a valid Endpoint
- validate_
flight_ name - Rules:
- validate_
formation_ name - Current Rules:
- validate_
id - The value may be a up to a 32byte hex encoded string
- validate_
inline_ flight_ spec - The value may be:
- validate_
name_ id - The arg can be any of:
- validate_
name_ id_ path - The arg can be any of:
- validate_
name_ id_ path_ inline - The arg can be any of:
- validate_
public_ endpoint - Ensures a valid Public Endpoint, we must special case Public Endpoints because it only supports the ‘http’ and ‘https’ protocol field.
- validate_
u64