Module seaplane_cli::cli::validator

source ·
Utility functions used to validate various argument types on the CLI. The arguments and return type are what the clap::Arg::validator expects.

Functions

The value may be path where path is some path that exists
The arg can be any of:
The value may be -