Module seaplane_cli::cli::validator

source ·
Utility functions used to validate various argument types on the CLI. The arguments and return type are what the clap::Arg::validator expects.

Functions

The value may be @path where path is some path that exists
The value may be @-
Ensures a valid Endpoint
The value may be a up to a 32byte hex encoded string
The arg can be any of:
The arg can be any of:
The arg can be any of:
Ensures a valid Public Endpoint, we must special case Public Endpoints because it only supports the ‘http’ and ‘https’ protocol field.