pub struct RawConfig {
    pub loaded_from: Vec<PathBuf>,
    pub did_init: bool,
    pub seaplane: RawSeaplaneConfig,
    pub account: RawAccountConfig,
    pub api: RawApiConfig,
    pub danger_zone: RawDangerZoneConfig,
    /* private fields */
}

Fields

loaded_from: Vec<PathBuf>did_init: bool

Did we run initialization automatically or not on startup?

seaplane: RawSeaplaneConfigaccount: RawAccountConfigapi: RawApiConfigdanger_zone: RawDangerZoneConfig

Implementations

source

impl RawConfig

source

pub fn load_all() -> Result<Self>

Loads the Raw configuration file (not de-conflicted with the CLI or ENV yet)

Loads configs from all platform specific locations, overriding values at each step