pub struct FlightCtx {
    pub image: Option<ImageReference>,
    pub name_id: String,
    pub minimum: u64,
    pub maximum: Option<u64>,
    pub architecture: Vec<ArchitectureModel>,
    pub api_permission: bool,
    pub reset_maximum: bool,
    pub generated_name: bool,
}
Represents the “Source of Truth” i.e. it combines all the CLI options, ENV vars, and config values into a single structure that can be used later to build models for the API or local structs for serializing

Fields

image: Option<ImageReference>name_id: Stringminimum: u64maximum: Option<u64>architecture: Vec<ArchitectureModel>api_permission: boolreset_maximum: boolgenerated_name: bool

Implementations

Builds a FlightCtx from a string value using the inline flight spec syntax:

name=FOO,image=nginx:latest,api-permission,architecture=amd64,minimum=1,maximum,2

Where only image=… is required

Builds a FlightCtx from ArgMatches using some prefix if any to search for args

Creates a new seaplane::api::compute::v1::Flight from the contained values