Struct seaplane_cli::context::flight::FlightCtx
source · pub struct FlightCtx {
pub image: Option<ImageReference>,
pub name_id: String,
pub minimum: u64,
pub maximum: Option<u64>,
pub architecture: Vec<ArchitectureModel>,
pub api_permission: bool,
pub reset_maximum: bool,
pub generated_name: bool,
}Expand description
Represents the “Source of Truth” i.e. it combines all the CLI options, ENV vars, and config values into a single structure that can be used later to build models for the API or local structs for serializing
Fields
image: Option<ImageReference>name_id: Stringminimum: u64maximum: Option<u64>architecture: Vec<ArchitectureModel>api_permission: boolreset_maximum: boolgenerated_name: boolImplementations
sourceimpl FlightCtx
impl FlightCtx
sourcepub fn from_inline_flight(
inline_flight: &str,
registry: &str
) -> Result<FlightCtx>
pub fn from_inline_flight(
inline_flight: &str,
registry: &str
) -> Result<FlightCtx>
Builds a FlightCtx from a string value using the inline flight spec syntax:
name=FOO,image=nginx:latest,api-permission,architecture=amd64,minimum=1,maximum,2
Where only image=… is required
sourcepub fn from_flight_common(
matches: &SeaplaneFlightCommonArgMatches<'_>,
ctx: &Ctx
) -> Result<FlightCtx>
pub fn from_flight_common(
matches: &SeaplaneFlightCommonArgMatches<'_>,
ctx: &Ctx
) -> Result<FlightCtx>
Builds a FlightCtx from ArgMatches using some prefix if any to search for args
sourcepub fn model(&self) -> FlightModel
pub fn model(&self) -> FlightModel
Creates a new seaplane::api::compute::v1::Flight from the contained values