pub struct FormationCfgCtx {
    pub flights: Vec<String>,
    pub affinities: Vec<String>,
    pub connections: Vec<String>,
    pub providers_allowed: HashSet<ProviderModel>,
    pub providers_denied: HashSet<ProviderModel>,
    pub regions_allowed: HashSet<RegionModel>,
    pub regions_denied: HashSet<RegionModel>,
    pub public_endpoints: Vec<Endpoint>,
    pub formation_endpoints: Vec<Endpoint>,
    pub flight_endpoints: Vec<Endpoint>,
}

Fields

flights: Vec<String>

String is a flight name because that’s the only thing shared by both local and remote

affinities: Vec<String>

String is a flight name because that’s the only thing shared by both local and remote

connections: Vec<String>

String is a flight name because that’s the only thing shared by both local and remote

providers_allowed: HashSet<ProviderModel>

Use actual API model since that is ultimately what we want

providers_denied: HashSet<ProviderModel>

Use actual API model since that is ultimately what we want

regions_allowed: HashSet<RegionModel>

Use actual API model since that is ultimately what we want

regions_denied: HashSet<RegionModel>

Use actual API model since that is ultimately what we want

public_endpoints: Vec<Endpoint>formation_endpoints: Vec<Endpoint>flight_endpoints: Vec<Endpoint>