pub struct FormationCtx {
    pub name_id: String,
    pub launch: bool,
    pub remote: bool,
    pub local: bool,
    pub grounded: bool,
    pub recursive: bool,
    pub cfg_ctx: FormationCfgCtx,
}
Represents the “Source of Truth” i.e. it combines all the CLI options, ENV vars, and config values into a single structure that can be used later to build models for the API or local structs for serializing

A somewhat counter-intuitive thing about Formations and their models is the there is no “Formation Model” only a “Formation Configuration Model” This is because a “Formation” so to speak is really just a named collection of configurations and info about their traffic weights/activation statuses.

Fields

name_id: Stringlaunch: boolremote: boollocal: boolgrounded: boolrecursive: boolcfg_ctx: FormationCfgCtx

Implementations

flight is the name of the argument for the Flight’s name/id

Creates a new seaplane::api::compute::v1::FormationConfiguration from the contained values