pub struct MetadataCtx {
    pub kvs: KeyValues,
    pub directory: Option<Directory>,
    pub base64: bool,
    pub decode: bool,
    pub decode_safe: bool,
    pub no_decode: bool,
    pub from: Option<Key>,
    pub no_header: bool,
    pub no_keys: bool,
    pub no_values: bool,
    pub keys_width_limit: usize,
    pub values_width_limit: usize,
}
Represents the “Source of Truth” i.e. it combines all the CLI options, ENV vars, and config values into a single structure that can be used later to build models for the API or local structs for serializing

Fields

kvs: KeyValuesdirectory: Option<Directory>base64: bool

Is the key or value already URL safe base64 encoded

decode: bool

Print with decoding

decode_safe: bool

Print with safe decoding

no_decode: bool

Print with no decoding

from: Option<Key>

A base64 encoded key

no_header: bool

Skip the KEY or VALUE header in –format=table

no_keys: bool

Don’t print keys

no_values: bool

Don’t print values

keys_width_limit: usize

Max width of keys

values_width_limit: usize

Max width of values

Implementations

Builds a MetadataCtx from ArgMatches

Builds a MetadataCtx from ArgMatches