Struct seaplane_cli::context::Args

source ·
pub struct Args {
    pub color: ColorChoice,
    pub name_id: Option<String>,
    pub overwrite: Vec<String>,
    pub exact: bool,
    pub all: bool,
    pub third_party: bool,
    pub shell: Option<Shell>,
    pub out_format: OutputFormat,
    pub force: bool,
    pub stateless: bool,
    pub api_key: Option<String>,
    pub fetch: bool,
}

Fields

color: ColorChoice

when the answer is “yes…but only if the stream is a TTY.” In these cases an enum of Never, Auto, Always would be more appropriate

Should be display ANSI color codes in output?

name_id: Option<String>

The name or local ID of an item

overwrite: Vec<String>

What to overwrite

exact: bool

Do items need to be exact to match

all: bool

Match all items

third_party: bool

Display third party licenses

shell: Option<Shell>

The shell to generate completions for

out_format: OutputFormat

How to display output

force: bool

Try to force the operation to happen

stateless: bool

Do not use local state files

api_key: Option<String>

The API Key associated with an account provided by the CLI, env, or Config used to request access tokens

fetch: bool

Should we fetch remote refs?

Implementations