pub struct Flights { /* private fields */ }Implementations
Sourceimpl Flights
impl Flights
Sourcepub fn add_from_at_strs<S>(&mut self, flights: Vec<S>) -> Result<Vec<String>>
pub fn add_from_at_strs<S>(&mut self, flights: Vec<S>) -> Result<Vec<String>>
Takes strings in the form of @- or @path and creates then adds them to the DB. Only one @- may be used or an Error is returned.
Returns a list of any created IDs
Sourcepub fn remove_indices(&mut self, indices: &[usize]) -> Vec<Flight>
pub fn remove_indices(&mut self, indices: &[usize]) -> Vec<Flight>
Removes any Flight definitions from the matching indices and returns a Vec of all removed Flights
Sourcepub fn indices_of_left_matches(&self, needle: &str) -> Vec<usize>
pub fn indices_of_left_matches(&self, needle: &str) -> Vec<usize>
Returns all indices of where the flight’s Name or ID (as hex) begins with the needle
Sourcepub fn indices_of_matches(&self, needle: &str) -> Vec<usize>
pub fn indices_of_matches(&self, needle: &str) -> Vec<usize>
Returns all indices of where the flight’s Name or ID (as hex) is an exact match of needle
pub fn iter(&self) -> impl Iterator<Item = &Flight>
pub fn clone_flight(&mut self, src: &str, exact: bool) -> Result<Flight>
Sourcepub fn update_or_create_flight(
&mut self,
model: &FlightModel,
) -> Vec<(String, Id)>
pub fn update_or_create_flight( &mut self, model: &FlightModel, ) -> Vec<(String, Id)>
Either updates a matching local flight, or creates a new one. Returns NEW flight names and IDs
pub fn update_flight( &mut self, src: &str, exact: bool, ctx: &FlightCtx, ) -> Result<()>
pub fn add_flight(&mut self, flight: Flight)
pub fn remove_flight(&mut self, src: &str, exact: bool) -> Result<Flight>
pub fn find_name(&self, name: &str) -> Option<&Flight>
pub fn find_name_or_partial_id(&self, needle: &str) -> Option<&Flight>