pub struct Flights { /* private fields */ }

Implementations

Takes strings in the form of @- or @path and creates then adds them to the DB. Only one @- may be used or an Error is returned.

Returns a list of any created IDs

Removes any Flight definitions from the matching indices and returns a Vec of all removed Flights

Returns all indices of where the flight’s Name or ID (as hex) begins with the needle

Returns all indices of where the flight’s Name or ID (as hex) is an exact match of needle

Either updates a matching local flight, or creates a new one. Returns NEW flight names and IDs