pub struct Flights { /* private fields */ }Implementations
sourceimpl Flights
impl Flights
sourcepub fn add_from_at_strs<S>(&mut self, flights: Vec<S>) -> Result<Vec<String>>where
S: AsRef<str>,
pub fn add_from_at_strs<S>(&mut self, flights: Vec<S>) -> Result<Vec<String>>where
S: AsRef<str>,
Takes strings in the form of @- or @path and creates then adds them to the DB. Only one @- may be used or an Error is returned.
Returns a list of any created IDs
sourcepub fn remove_indices(&mut self, indices: &[usize]) -> Vec<Flight>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn remove_indices(&mut self, indices: &[usize]) -> Vec<Flight>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
Removes any Flight definitions from the matching indices and returns a Vec of all removed Flights
sourcepub fn indices_of_left_matches(&self, needle: &str) -> Vec<usize>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn indices_of_left_matches(&self, needle: &str) -> Vec<usize>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
Returns all indices of where the flight’s Name or ID (as hex) begins with the needle
sourcepub fn indices_of_matches(&self, needle: &str) -> Vec<usize>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn indices_of_matches(&self, needle: &str) -> Vec<usize>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
Returns all indices of where the flight’s Name or ID (as hex) is an exact match of needle
pub fn iter(&self) -> impl Iterator<Item = &Flight>
pub fn clone_flight(&mut self, src: &str, exact: bool) -> Result<Flight>
sourcepub fn update_or_create_flight(
&mut self,
model: &FlightModel
) -> Vec<(String, Id)>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn update_or_create_flight(
&mut self,
model: &FlightModel
) -> Vec<(String, Id)>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
Either updates a matching local flight, or creates a new one. Returns NEW flight names and IDs
pub fn update_flight(
&mut self,
src: &str,
exact: bool,
ctx: &FlightCtx
) -> Result<()>
pub fn add_flight(&mut self, flight: Flight)
pub fn remove_flight(&mut self, src: &str, exact: bool) -> Result<Flight>
pub fn find_name(&self, name: &str) -> Option<&Flight>
pub fn find_name_or_partial_id(&self, needle: &str) -> Option<&Flight>