pub struct Formations {
    pub formations: Vec<Formation>,
    pub configurations: Vec<FormationConfiguration>,
    /* private fields */
}
This struct represents a Local Formation. I.e. one the user can interact with on the CLI and can be (de)serialized locally.

A somewhat counter-intuitive thing about “Formations” and their models is the there is no “Formation Model” only a “Formation Configuration Model” This is because a “Formation” so to speak is really just a named collection of configurations and info about their traffic weights/activation statuses.

Fields

formations: Vec<Formation>

A list of “Formation“s

configurations: Vec<FormationConfiguration>

A list of “Formation Configuration“s

We keep these separate from the Formation themselves because multiple formations can reference the same configuration.

Implementations

Returns the removed FormationConfiguration by ID or None if there was no match

DANGER: this will invalidate any previously held indices after the removed item

Either updates a matching local Formation Configurations, or creates a new one. Returns the existing ID of the config that was updated if any

Either updates a matching local Formations by replacing the local IDs, or creates a new one. Returns NEW Formations IDs

Returns true if there is a Formation with the given name

Removes an exact name match, returning the removed Formation or None if nothing matched.

DANGER: this will invalidate any previously held indices after the removed item

Returns the index of an exact name match

Returns all indices of an exact name or partial ID match

Returns all indices of a partial name or ID match

Removes all indices

Removes the given flight from all formations that reference it