pub struct KeyValue {
    pub key: EncodedString,
    pub value: EncodedString,
}
We use our own KeyValue instead of the models because we need to not enforce base64 encoding, and implement a bunch of additional methods and traits that wouldn’t make sense for the models

We also need to keep track if the values are encoded or not

Fields

key: EncodedStringvalue: EncodedString

Implementations

Creates a new KeyValue from an encoded key and value. You must pinky promise the key and value are URL safe base64 encoded or Bad Things may happen.

Creates a new KeyValue from an un-encoded key and value, encoding them along the way

Creates a new KeyValue from an un-encoded string ref, encoding it along the way

Creates a new KeyValue from an already encoded string ref. You must pinky promise the key is URL safe base64 encoded or Bad Things may happen.

Sets the value to some base64 encoded value